Learn R Programming

TroublemakeR (version 0.0.1)

species_names: Species names

Description

This function takes a vector of species names and writes them to a .dat file. The file will be written to the location specified by the name argument. If the file already exists, it will be overwritten. The file format is plain text, with each line terminated by a newline character.

Usage

species_names(species_names = NULL, name = "Problem")

Value

.dat file. This function is used for the side-effect of writing values to a file.

Arguments

species_names

a vector with the names of species

name

The name of the output file

Author

Derek Corcoran

Examples

Run this code

species_names(species_names = c("Spp1", "Spp2"))
file.remove("Problem.dat")

Run the code above in your browser using DataLab