This function takes a vector of species names and writes them to a .dat file. The file
will be written to the location specified by the name argument. If the file
already exists, it will be overwritten. The file format is plain text, with each
line terminated by a newline character.
Usage
species_names(species_names = NULL, name = "Problem")
Value
.dat file. This function is used for the side-effect of writing values to a file.